<?php

class THR_Posts_Widget extends WP_Widget {

	var $defaults;

	function __construct() {
		$widget_ops = array( 'classname' => 'thr_posts_widget', 'description' => esc_html__('Display your posts with this widget', 'throne-buddy') );
		$control_ops = array( 'id_base' => 'thr_posts_widget' );
		parent::__construct( 'thr_posts_widget', esc_html__('Throne Posts', 'throne-buddy'), $widget_ops, $control_ops );

		$this->defaults = array(
			'title' => esc_html__( 'Featured Posts', 'throne-buddy' ),
			'numposts' => 5,
			'category' => array(),
			'tag'   => array(),
			'orderby' => 'date',
			'title_limit' => 53,
			'title_more' => '...',
			'date_limit' => 0,
			'auto_detect' => 0,
			'meta' => 0,
			'manual' => array()
		);
	}

	
	function widget( $args, $instance ) {
		extract( $args );
		$instance = wp_parse_args( (array) $instance, $this->defaults );
		
		echo wp_kses_post( $before_widget );

		$title = apply_filters('widget_title', $instance['title'] );

		if ( !empty($title) ) {
			echo wp_kses_post( $before_title . $title . $after_title );
		}
	
		$q_args = array(
			'post_type'=> 'post',
			'posts_per_page' => $instance['numposts'],
			'ignore_sticky_posts' => 1,
			'orderby' => $instance['orderby']
		);


		if ( !empty( $instance['manual'] ) && !empty( $instance['manual'][0] ) ) {
			$q_args['posts_per_page'] = absint( count( $instance['manual'] ) );
			$q_args['orderby'] =  'post__in';
			$q_args['post__in'] =  $instance['manual'];
			$q_args['post_type'] = array_keys( get_post_types( array( 'public' => true ) ) ); //support all existing public post types

		} else {

			if ( !empty( $instance['auto_detect'] ) && is_single() ) {

				$cats = get_the_category();

				if ( !empty( $cats ) ) {
					foreach ( $cats as $k => $cat ) {
						$q_args['category__in'][] = $cat->term_id;
					}
				}

			} else {

				if ( !empty( $instance['category'] ) ) {
					$q_args['category__in'] = ( is_array( $instance['category'] ) ) ? $instance['category'] : array( $instance['category'] );
				}
			}

			if ( !empty( $instance['tag'] ) ) :
				$q_args['tag_slug__in'] = explode( ',', $instance['tag'] );
			endif;

			if ( $instance['orderby'] == 'views' && function_exists( 'ev_get_meta_key' ) ) {
				$q_args['orderby'] = 'meta_value_num';
				$q_args['meta_key'] = ev_get_meta_key();
			}

			if ( $instance['orderby'] == 'title' ) {
				$q_args['order'] = 'ASC';
			}


			if ( !empty( $instance['date_limit'] ) ) {
				$q_args['date_query'] = array(
					'after' => date( 'Y-m-d', thr_calculate_time_diff( $instance['date_limit'] ) )
				);
			}
		}

		$thr_posts = new WP_Query($q_args);
		
		$title_limit = isset($instance['title_limit']) && !empty($instance['title_limit']) ? $instance['title_limit'] : false;
		$title_more = isset($instance['title_more']) ? $instance['title_more'] : '...';
		if($thr_posts->have_posts()): ?>
		 
		<ul>			
			
			<?php	while($thr_posts->have_posts()) : $thr_posts->the_post(); ?>
		 	
		 		<li>
		 			<?php
		 				$p_title = $title_limit ? thr_trim_chars(get_the_title(), $title_limit, $title_more) : get_the_title();
		 			?>
		 		

		 			<span class="featured_image_sidebar">

		 			<?php echo thr_featured_image('thr-layout-c'); ?>
		 			<a href="<?php echo esc_url(get_permalink()); ?>" class="featured_item_overlay"></a>
		 			<span class="featured_title_over">
	 				<?php if(!empty($instance['meta']) && $meta = thr_get_meta_data('',$instance['meta'])): ?>
		 				<span class="entry-meta"><?php echo wp_kses_post( $meta );?></span>
		 			<?php endif; ?>
		 			<a href="<?php echo esc_url(get_permalink()); ?>" class="featured_posts_link"><?php echo wp_kses_post( $p_title ); ?></a>
		 			</span>
		 			</span>
		 			
	


		 		</li>
			<?php endwhile; ?>
			 
		  </ul>
		<?php endif; ?>
		
		<?php wp_reset_postdata(); ?>
		
		<?php
		echo wp_kses_post( $after_widget );
	}

	
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['orderby'] = $new_instance['orderby'];
		$instance['category'] = $new_instance['category'];
		$instance['tag'] = $new_instance['tag'];
		$instance['numposts'] = absint( $new_instance['numposts'] );
		$instance['title_limit'] = absint( $new_instance['title_limit'] );
		$instance['title_more'] = strip_tags($new_instance['title_more']);
		$instance['date_limit'] = $new_instance['date_limit'];
		$instance['auto_detect'] = isset( $new_instance['auto_detect'] ) ? 1 : 0;
		$instance['meta'] = $new_instance['meta'];
		$instance['manual'] = !empty( $new_instance['manual'] ) ? explode( ",", $new_instance['manual'] ) : array();

		return $instance;
	}

	function form( $instance ) {
	
		$instance = wp_parse_args( (array) $instance, $this->defaults ); ?>
				
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e('Title', 'throne-buddy'); ?>:</label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" type="text" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr($instance['title']); ?>" class="widefat" />
		</p>

		<p>
		 	<label for="<?php echo esc_attr( $this->get_field_id( 'numposts' ) ); ?>"><?php esc_html_e('Number of posts to show', 'throne-buddy'); ?>:</label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'numposts' ) ); ?>" type="text" name="<?php echo esc_attr( $this->get_field_name( 'numposts' ) ); ?>" value="<?php echo absint($instance['numposts']); ?>" class="small-text" />
		</p>

		<p>
			<?php $this->widget_tax( $this, 'category', $instance['category'] ); ?>
		</p>

		<p>
			<input id="<?php echo esc_attr( $this->get_field_id( 'auto_detect' ) ); ?>" type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'auto_detect' ) ); ?>" value="1" <?php checked( 1, $instance['auto_detect'] ); ?>/>
			<label for="<?php echo esc_attr( $this->get_field_id( 'auto_detect' ) ); ?>"><?php esc_html_e( 'Auto detect category', 'throne-buddy' ); ?></label>
			<small class="howto"><?php esc_html_e( 'If sidebar is used on single post template, display posts from current post category ', 'throne-buddy' ); ?></small>
		</p>

		<?php $tags = ( is_array( $instance['tag'] ) ) ? implode( ",", $instance['tag'] ) : $instance['tag'];?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'tag' ) ); ?>"><?php esc_html_e( 'Select tags', 'throne-buddy' ); ?>:</label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'tag' ) ); ?>" type="text" name="<?php echo esc_attr( $this->get_field_name( 'tag' ) ); ?>" value="<?php echo esc_attr( $tags ) ?>" class="widefat" />
			<small class="howto"><?php esc_html_e( 'Specify tag slugs separated by comma if you want to select only those tags. i.e. sugar, spice, everything-nice.', 'throne-buddy' ); ?></small>
		</p>

		<p>
		  	<?php $this->widget_orderby( $this, $instance['orderby'] ); ?>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'date_limit' ) ); ?>"><?php esc_html_e('Only select posts which are not older than', 'throne-buddy'); ?>:</label>
			<select id="<?php echo esc_attr( $this->get_field_id( 'date_limit' ) ); ?>" type="text" name="<?php echo esc_attr( $this->get_field_name( 'date_limit' ) ); ?>" class="widefat">
				<?php $dates = $this->dates_q(); ?>
				<?php foreach($dates as $key => $value): ?>
					<option value="<?php echo esc_attr( $key ); ?>" <?php selected($instance['date_limit'], $key, true); ?>><?php echo esc_html( $value );?></option>
				<?php endforeach; ?>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'manual' ) ); ?>"><?php esc_html_e( 'Choose manually', 'throne-buddy' ); ?>:</label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'manual' ) ); ?>" type="text" name="<?php echo esc_attr( $this->get_field_name( 'manual' ) ); ?>" value="<?php echo implode( ",", $instance['manual'] ); ?>" class="widefat" />
			<small class="howto"><?php esc_html_e( 'Specify post ids separated by comma if you want to select only those posts. i.e. 213,32,12,45 Note: you can also choose pages as well as custom post types', 'throne-buddy' ); ?></small>
		</p>

		<p>
		   	 <label for="<?php echo esc_attr( $this->get_field_id( 'title_limit' ) ); ?>"><?php esc_html_e('Post titles characters limit', 'throne-buddy'); ?>:</label>
			 <input id="<?php echo esc_attr( $this->get_field_id( 'title_limit' ) ); ?>" type="text" name="<?php echo esc_attr( $this->get_field_name( 'title_limit' ) ); ?>" value="<?php echo absint($instance['title_limit']); ?>" class="small-text" />
			 <small class="howto"><?php esc_html_e('Note: Leave empty if you want to show entire post titles', 'throne-buddy'); ?></small>
		</p>

		<p>
		   	 <label for="<?php echo esc_attr( $this->get_field_id( 'title_more' ) ); ?>"><?php esc_html_e('Posts titles more string', 'throne-buddy'); ?>:</label>
			 <input id="<?php echo esc_attr( $this->get_field_id( 'title_more' ) ); ?>" type="text" name="<?php echo esc_attr( $this->get_field_name( 'title_more' ) ); ?>" value="<?php echo esc_attr($instance['title_more']); ?>" class="small-text" />
		</p>

		<p>
		  		<?php $this->widget_meta( $this, $instance['meta'] ); ?>
		</p>
	   
	<?php
	}

	function dates_q(){
		$dates = array(
			'-1 day' => esc_html__('1 Day', 'throne-buddy'),
			'-1 week' => esc_html__('1 Week', 'throne-buddy'),
			'-1 month' => esc_html__('1 Month', 'throne-buddy'),
			'-3 months' => esc_html__('3 Months', 'throne-buddy'),
			'-6 months' => esc_html__('6 Months', 'throne-buddy'),
			'-1 year' => esc_html__('1 Year', 'throne-buddy'),
			'0' => esc_html__('Select all posts', 'throne-buddy')
		);

		return $dates;
	}

	function widget_tax( $widget_instance, $taxonomy, $selected_taxonomy = false ) {
		if ( !empty( $widget_instance ) && !empty( $taxonomy ) ) :
			$categories = get_terms( $taxonomy, 'orderby=name&hide_empty=0' );
		?>
				<label for="<?php echo esc_attr( $widget_instance->get_field_id( 'category' ) ); ?>"><?php esc_html_e( 'Choose from:', 'throne-buddy' ); ?></label><br/>
					<?php foreach ( $categories as $category ) : ?>
						<input type="checkbox" name="<?php echo esc_attr( $widget_instance->get_field_name( 'category' ) ); ?>[]" value="<?php echo esc_attr( $category->term_id ); ?>" <?php echo in_array( $category->term_id, (array)$selected_taxonomy ) ? 'checked': ''?> /> <?php echo esc_html( $category->name ); ?><br/>
					<?php endforeach; ?>
		<?php
		endif;
	}

	function widget_orderby( $widget_instance = false, $orderby = false ) {

		$orders = array(
			'date' => esc_html__( 'Date', 'throne-buddy' ),
			'comment_count' => esc_html__( 'Number of comments', 'throne-buddy' ),
			'views' => esc_html__( 'Number of views', 'throne-buddy' ),
			'rand' => esc_html__( 'Random', 'throne-buddy' )
		);


		if ( !empty( $widget_instance ) ) { ?>
				<label for="<?php echo esc_attr( $widget_instance->get_field_id( 'orderby' ) ); ?>"><?php esc_html_e( 'Order by:', 'throne-buddy' ); ?></label>
				<select id="<?php echo esc_attr( $widget_instance->get_field_id( 'orderby' ) ); ?>" name="<?php echo esc_attr( $widget_instance->get_field_name( 'orderby' ) ); ?>" class="widefat">
					<?php foreach ( $orders as $key => $order ) { ?>
						<option value="<?php echo esc_attr( $key ); ?>" <?php selected( $orderby, $key );?>><?php echo esc_html( $order ); ?></option>
					<?php } ?>
				</select>
		<?php }
	}

	function widget_meta( $widget_instance = false, $current = false ) {

		$metas = array(
			'0' => esc_html__( 'None', 'throne-buddy' ),
			'date' => esc_html__( 'Date/time', 'throne-buddy' ),
            'author' => esc_html__( 'Author', 'throne-buddy' ),
            'comments' => esc_html__( 'Comments', 'throne-buddy' ),
            'categories' => esc_html__( 'Categories', 'throne-buddy' ),
            'views' => esc_html__( 'Views', 'throne-buddy' ),
            'rtime' => esc_html__( 'Reading time', 'throne-buddy' ),

		);

		if ( !empty( $widget_instance ) ) { ?>
				<label for="<?php echo esc_attr( $widget_instance->get_field_id( 'meta' ) ); ?>"><?php esc_html_e( 'Display meta data:', 'throne-buddy' ); ?></label>
				<select id="<?php echo esc_attr( $widget_instance->get_field_id( 'meta' ) ); ?>" name="<?php echo esc_attr( $widget_instance->get_field_name( 'meta' ) ); ?>" class="widefat">
					<?php foreach ( $metas as $id => $title ) { ?>
						<option value="<?php echo esc_attr( $id ); ?>" <?php selected( $current, $id );?>><?php echo esc_html( $title ); ?></option>
					<?php } ?>
				</select>
		<?php }
	}
}

?>