<?php

/* Load admin scripts and styles */
add_action( 'admin_enqueue_scripts', 'thr_load_admin_scripts' );


/**
 * Load scripts and styles in admin
 *
 * It just wrapps two other separate functions for loading css and js files in admin
 *
 * @since  1.8
 */

function thr_load_admin_scripts() {
	thr_load_admin_css();
	thr_load_admin_js();
}


/**
 * Load admin css files
 *
 * @since  1.8
 */

function thr_load_admin_css() {

	//Load small admin style tweaks
	wp_enqueue_style( 'thr_admin_css', get_parent_theme_file_uri( '/assets/css/admin/global.css' ) , false, THRONE_THEME_VERSION);

}



/**
 * Load admin js files
 *
 * @since  1.8
 */

function thr_load_admin_js() {

	global $pagenow, $typenow;

	wp_enqueue_script( 'thr_global_js', get_parent_theme_file_uri( '/assets/js/admin/global.js' ), array( 'jquery' ), THRONE_THEME_VERSION, true );

	if ( in_array( $pagenow , array( 'post.php', 'post-new.php' ) ) && $typenow == 'page' ) {

		wp_enqueue_script( 'thr_metabox_page_js', get_parent_theme_file_uri( '/assets/js/admin/metabox-page.js' ), array( 'jquery' ), THRONE_THEME_VERSION, true );
		wp_localize_script( 'thr_metabox_page_js', 'thr_js_settings', thr_get_admin_js_settings() );

	}

}


/**
 * Load editor styles
 *
 * @since  1.8
 */

function thr_load_editor_styles() {

	if ( $fonts_link = thr_generate_font_links() ) {
		add_editor_style( $fonts_link );
	}

	add_editor_style( get_parent_theme_file_uri( '/assets/css/admin/editor-style.css' ) );

}

/**
 * Load dynamic editor styles
 *
 * @since  1.8
 */

add_action( 'enqueue_block_editor_assets', 'thr_block_editor_styles', 99 );

function thr_block_editor_styles() {

	wp_register_style( 'thr-editor-styles', false, THRONE_THEME_VERSION );
	wp_enqueue_style( 'thr-editor-styles' );

	wp_add_inline_style( 'thr-editor-styles', thr_generate_dynamic_editor_css() );

}

?>
