<?php

/* Show admin notices */

add_action( 'admin_init', 'thr_check_installation' );

if ( !function_exists( 'thr_check_installation' ) ):
	function thr_check_installation() {
		add_action( 'admin_notices', 'thr_welcome_msg', 1 );
		add_action( 'admin_notices', 'thr_update_msg', 1 );
		add_action( 'admin_notices', 'thr_required_plugins_msg', 1 );
	}
endif;


/* Show welcome message and quick tips after theme activation */

if ( !function_exists( 'thr_welcome_msg' ) ):
	function thr_welcome_msg() {
		
		if ( get_option( 'thr_welcome_box_displayed' ) || get_option( 'merlin_throne_completed' ) ) {
			return false;
		}
		
		update_option( 'thr_theme_version', THRONE_THEME_VERSION );
		include_once get_parent_theme_file_path( 'core/admin/welcome-panel.php' );
		
	}
endif;


/* Show message box after theme update */

if ( !function_exists( 'thr_update_msg' ) ):
	function thr_update_msg() {
		
		if ( !get_option( 'thr_welcome_box_displayed' ) && !get_option( 'merlin_throne_completed' ) ) {
			return false;
		}

		$prev_version = get_option( 'thr_theme_version' );

		$cur_version = THRONE_THEME_VERSION;
		if ( $prev_version === false ) {$prev_version = '0.0.0';}
	
		if ( version_compare( $cur_version, $prev_version, '>' ) ) {
			include_once get_parent_theme_file_path( 'core/admin/update-panel.php' );
		}
		
	}
endif;


/**
 * Display message if required plugins are not installed and activated
 *
 * @since  1.0
 */

if ( !function_exists( 'thr_required_plugins_msg' ) ):
	function thr_required_plugins_msg() {

		if ( !get_option( 'thr_welcome_box_displayed' ) && !get_option( 'merlin_throne_completed' ) ) {
			return false;
		}

		if ( !thr_is_redux_active() ) {
			$class = 'notice notice-error';
			$message = wp_kses_post( sprintf( __( 'Important: Redux Framework plugin is required to run your theme options panel. Please visit <a href="%s">recommended plugins page</a> to install it.', 'throne' ), admin_url( 'admin.php?page=install-required-plugins' ) ) );
			printf( '<div class="%1$s"><p>%2$s</p></div>', $class, $message );
		}

	}
endif;

/* Store registered sidebars so you can get them before wp_registered_sidebars is initialized to use them in theme options */

if ( !function_exists( 'thr_check_sidebars' ) ):
	function thr_check_sidebars() {
		global $wp_registered_sidebars;
		if ( !empty( $wp_registered_sidebars ) ) {
			update_option( 'thr_registered_sidebars', $wp_registered_sidebars );
		}
	}
endif;

add_action( 'admin_init', 'thr_check_sidebars' );



/**
 * Check for Additional CSS in Theme Options and transfer it to Customize -> Additional CSS
 *
 * @return void
 * @since  1.8
 */

if ( !function_exists( 'thr_patch_additional_css' ) ) :
	function thr_patch_additional_css() {

		$additional_css = thr_get_option( 'additional_css' );

		if ( empty( $additional_css ) ) {
			return false;
		}
		
		global $thr_settings;

		$thr_settings = get_option( 'thr_settings' ); 

		$thr_settings['additional_css'] = '';

		update_option( 'thr_settings', $thr_settings ) ;


		$customize_css = wp_get_custom_css_post();
		
		if ( !empty( $customize_css ) && !is_wp_error( $customize_css ) ) {
			$additional_css .= $customize_css->post_content;
		}

		wp_update_custom_css_post($additional_css);
	}
endif;

add_action('admin_init','thr_patch_additional_css');


/**
 * Patching for social share platforms for meks easy share plugin
 *
 * @return void
 * @since  1.8
 */
add_action('admin_init','thr_patch_social_share_platforms');

if ( !function_exists( 'thr_patch_social_share_platforms' ) ) :
	function thr_patch_social_share_platforms() {

		$social_platforms = thr_get_option( 'social_share' );

		if ( empty( $social_platforms ) ) {
			return false;
		}
		
		global $thr_settings;
		$thr_settings = get_option( 'thr_settings' ); 

		$thr_settings['social_share'] = '';
		update_option( 'thr_settings', $thr_settings ) ;
		
		$new_platforms = array();

		foreach ( $social_platforms as $platform => $value ) {
			if ( $value == '1' ) {
				$new_platforms['platforms'][] = $platform;
			}
		}

		update_option( 'meks_ess_settings', $new_platforms );

	}
endif;


/**
 * Filter for social share option fields
 *
 * @param array $args - Array of default fields
 * @return array
 * @since  1.8
 */
add_filter( 'meks_ess_modify_options_fields', 'thr_social_share_option_fields_filter' );

if ( !function_exists( 'thr_social_share_option_fields_filter' ) ):
	function thr_social_share_option_fields_filter( $args ) {
		
		unset( $args['style'] );
		unset( $args['variant'] );
		unset( $args['color'] );
		unset( $args['location'] );
		unset( $args['post_type'] );
		unset( $args['label_share'] );

		return $args;
	}
endif;



/**
 * Check for Favicon Option Theme Options and transfer it to Customize -> Favicon
 *
 * @return void
 * @since  1.8
 */

if ( !function_exists( 'thr_patch_favicon' ) ) :
	function thr_patch_favicon() {

		$favicon = thr_get_option( 'favicon' );

		if ( empty( $favicon ) ) {
			return false;
		}

		$thr_options = get_option( 'thr_settings' );
		$thr_options['favicon'] = '';
		update_option( 'thr_settings', $thr_options ) ;

		$image_id = thr_get_image_id_by_url( $favicon );

		if ( empty( $image_id ) ) {
			return false;
		}

		update_option( 'site_icon', $image_id ) ;

	}
endif;

add_action( 'admin_init', 'thr_patch_favicon' );


/**
 * Add Meks dashboard widget
 *
 * @since  1.0
 */

add_action( 'wp_dashboard_setup', 'thr_add_dashboard_widgets' );

if ( !function_exists( 'thr_add_dashboard_widgets' ) ):
	function thr_add_dashboard_widgets() {
		add_meta_box( 'thr_dashboard_widget', 'Meks - WordPress Themes & Plugins', 'thr_dashboard_widget_cb', 'dashboard', 'side', 'high' );
	}
endif;


/**
 * Meks dashboard widget
 *
 * @since  1.0
 */
if ( !function_exists( 'thr_dashboard_widget_cb' ) ):
	function thr_dashboard_widget_cb() {

		$transient = 'thr_mksaw';
		$hide = '<style>#thr_dashboard_widget{display:none;}</style>';

		$data = get_transient( $transient );
	
		if ( $data == 'error' ) {
			echo $hide;
			return;
		}

		if ( !empty( $data ) ) {
			echo $data;
			return;
		}

		$url = 'https://demo.mekshq.com/mksaw.php';
		$args = array( 'body' => array( 'key' => md5( 'meks' ), 'theme' => 'throne' ) );
		$response = wp_remote_post( $url, $args );

		if ( is_wp_error( $response ) ) {
			set_transient( $transient, 'error', DAY_IN_SECONDS );
			echo $hide;
			return;
		}

		$json = wp_remote_retrieve_body( $response );

		if ( empty( $json ) ) {
			set_transient( $transient, 'error', DAY_IN_SECONDS );
			echo $hide;
			return;
		}

		$json = json_decode( $json );

		if ( !isset( $json->data ) ) {
			set_transient( $transient, 'error', DAY_IN_SECONDS );
			echo $hide;
			return;
		} 

		set_transient( $transient, $json->data, DAY_IN_SECONDS );
		echo $json->data;
		
	}
endif;

?>