<?php 

/* Get all sidebars */
if ( !function_exists( 'thr_get_sidebars_list' ) ):
	function thr_get_sidebars_list( $inherit = false ) {

		$sidebars = array();

		if ( $inherit ) {
			$sidebars['inherit'] = esc_html__( 'Inherit', 'throne' );
		}

		$sidebars['0'] = esc_html__( 'None', 'throne' );

		global $wp_registered_sidebars;

		if ( !empty( $wp_registered_sidebars ) ) {

			foreach ( $wp_registered_sidebars as $sidebar ) {
				$sidebars[$sidebar['id']] = $sidebar['name'];
			}

		} else {

			//Get sidebars from wp_options if global var is not loaded yet
			$fallback_sidebars = get_option( 'thr_registered_sidebars' );
			if ( !empty( $fallback_sidebars ) ) {
				foreach ( $fallback_sidebars as $sidebar ) {
					if ( !array_key_exists( $sidebar['id'], $sidebars ) ) {
						$sidebars[$sidebar['id']] = $sidebar['name'];
					}
				}
			}

			//Check for theme additional sidebars
			$custom_sidebars = thr_get_option( 'add_sidebars' );

			if ( empty( $custom_sidebars ) ) {
				$settings = get_option( 'thr_settings' );
				$custom_sidebars = isset( $settings['add_sidebars'] ) ? $settings['add_sidebars'] : false;
			}

			if ( $custom_sidebars ) {
				for ( $i = 1; $i <= $custom_sidebars; $i++ ) {
					if ( !array_key_exists( 'thr_custom_sidebar_'.$i, $sidebars ) ) {
						$sidebars['thr_custom_sidebar_'.$i] = esc_html__( 'Additional Sidebar', 'throne' ).' '.$i;
					}
				}
			}
		}

		return $sidebars;
	}
endif;

/* Get sidebar layouts */
if ( !function_exists( 'thr_get_sidebar_layouts' ) ):
	function thr_get_sidebar_layouts( $inherit = false ) {
		$sidebars = array();
		if ( $inherit ) {
			$sidebars['inherit'] = esc_html__( 'Inherit', 'throne' );
		}
		$sidebars['0'] = esc_html__( 'No sidebar (full width content)', 'throne' );
		$sidebars['left'] = esc_html__( 'Left sidebar', 'throne' );
		$sidebars['right'] = esc_html__( 'Right sidebar', 'throne' );
		return $sidebars;
	}
endif;


if ( !function_exists( 'thr_get_time_diff_opts' ) ) :

	/**
	 * Retrieves time range options
	 * 
	 * This is a simple helper function that's being used to retrieve time range options.
	 * 
	 * @return array $options - Array of post order options
	 * @since 1.6
	 */
	function thr_get_time_diff_opts() {

		$options = array(
			'-1 day' => esc_html__( '1 Day', 'throne' ),
			'-3 days' => esc_html__( '3 Days', 'throne' ),
			'-1 week' => esc_html__( '1 Week', 'throne' ),
			'-1 month' => esc_html__( '1 Month', 'throne' ),
			'-3 months' => esc_html__( '3 Months', 'throne' ),
			'-6 months' => esc_html__( '6 Months', 'throne' ),
			'-1 year' => esc_html__( '1 Year', 'throne' ),
			'0' => esc_html__( 'All time', 'throne' )
		);

		//Allow child themes or plugins to change these options
		$options = apply_filters( 'thr_modify_time_diff_opts', $options );

		return $options;
	}
endif;


/* Get post listing layouts */
if ( !function_exists( 'thr_get_post_layouts' ) ):
	function thr_get_post_layouts( $inherit = false ) {
		$layouts = array(
			'layout-a' => array( 'title' => esc_html__( 'Layout A', 'throne' ), 'img' => get_parent_theme_file_uri('/assets/images/layout_a.png') ),
			'layout-b' => array( 'title' => esc_html__( 'Layout B', 'throne' ), 'img' => get_parent_theme_file_uri('/assets/images/layout_b.png') ),
			'layout-c' => array( 'title' => esc_html__( 'Layout C', 'throne' ), 'img' => get_parent_theme_file_uri('/assets/images/layout_c.png') ),
			'layout-d' => array( 'title' => esc_html__( 'Layout D', 'throne' ), 'img' => get_parent_theme_file_uri('/assets/images/layout_d.png') )
		);

		if ( $inherit ) {
			$layouts = array_merge( array( 'inherit' => array( 'title' => esc_html__( 'Inherit', 'throne' ) ) ), $layouts );
		}

		return $layouts;
	}
endif;


/* Get featured area layouts */
if ( !function_exists( 'thr_featured_area_layouts' ) ):
	function thr_featured_area_layouts( $inherit = false ) {
		$layouts = array(
			'2_0' => array( 'title' => esc_html__( '2 posts inline', 'throne' ), 'img' => get_parent_theme_file_uri('/assets/images/2_posts_inline.png') ),
			'3_0' => array( 'title' => esc_html__( '3 posts inline', 'throne' ), 'img' => get_parent_theme_file_uri('/assets/images/3_posts_inline.png') ),
			'4_0' => array( 'title' => esc_html__( '4 posts inline', 'throne' ), 'img' => get_parent_theme_file_uri('/assets/images/4_posts_inline.png') ),
			'2_2' => array( 'title' => wp_kses_post( __( '4 posts <span>(2 top + 2 bottom)</span>', 'throne' ) ),  'img' => get_parent_theme_file_uri('/assets/images/2_2_posts.png') ),
			'2_3' => array( 'title' => wp_kses_post( __( '5 posts <span>(2 top + 3 bottom)</span>', 'throne' ) ), 'img' => get_parent_theme_file_uri('/assets/images/2_3_posts.png') ),
			'2_4' => array( 'title' => wp_kses_post( __( '6 posts <span>(2 top + 4 bottom)</span>', 'throne' ) ), 'img' => get_parent_theme_file_uri('/assets/images/2_4_posts.png') ),
			'3_2' => array( 'title' => wp_kses_post( __( '5 posts <span>(3 top + 2 bottom)</span>', 'throne' ) ), 'img' => get_parent_theme_file_uri('/assets/images/3_2_posts.png') ),
			'3_3' => array( 'title' => wp_kses_post( __( '6 posts <span>(3 top + 3 bottom)</span>', 'throne' ) ), 'img' => get_parent_theme_file_uri('/assets/images/3_3_posts.png') ),
			'3_4' => array( 'title' => wp_kses_post( __( '7 posts <span>(3 top + 4 bottom)</span>', 'throne' ) ), 'img' => get_parent_theme_file_uri('/assets/images/3_4_posts.png') ),
			'4_2' => array( 'title' => wp_kses_post( __( '6 posts <span>(4 top + 2 bottom)</span>', 'throne' ) ), 'img' => get_parent_theme_file_uri('/assets/images/4_2_posts.png') ),
			'4_3' => array( 'title' => wp_kses_post( __( '7 posts <span>(4 top + 3 bottom)</span>', 'throne' ) ), 'img' => get_parent_theme_file_uri('/assets/images/4_3_posts.png') ),
			'4_4' => array( 'title' => wp_kses_post( __( '8 posts <span>(4 top + 4 bottom)</span>', 'throne' ) ), 'img' => get_parent_theme_file_uri('/assets/images/4_4_posts.png') )
		);

		if ( $inherit ) {
			$layouts = array_merge( array( 'inherit' => array( 'title' => esc_html__( 'Inherit', 'throne' ) ), '0' => array( 'title' => esc_html__( 'None', 'throne' ) ) ), $layouts );
		}

		return $layouts;
	}
endif;



if ( !function_exists( 'thr_get_post_order_opts' ) ) :

	/**
	 * Retrieves post ordering options
	 * 
	 * This is a simple helper function that's being used to retrieve post ordering options.
	 * 
	 * @return array $options - Array of post order options
	 * @since 1.5
	 */

	function thr_get_post_order_opts() {

		$options = array(
			'date' => esc_html__( 'Date', 'throne' ),
			'comment_count' => esc_html__( 'Number of comments', 'throne' ),
			'views' => esc_html__( 'Number of views', 'throne' ),
			'rand' => esc_html__( 'Random', 'throne' )

		);

		//Allow child themes or plugins to change these options
		$options = apply_filters( 'thr_modify_post_order_opts', $options );

		return $options;
	}
endif;


/**
 * Generate dynamic editor css
 *
 * Function parses theme options and generates css code dynamically
 *
 * @return string Generated css code
 * @since  1.0
 */
if ( !function_exists( 'thr_generate_dynamic_editor_css' ) ):
	function thr_generate_dynamic_editor_css() {
		ob_start();
		get_template_part( 'assets/css/admin/dynamic-editor-css' );
		$output = ob_get_contents();
		ob_end_clean();
		$output = thr_compress_css_code( $output );

		return $output;
	}
endif;


/* Get update notification */
if ( !function_exists( 'thr_get_update_notification' ) ):
	function thr_get_update_notification() {
		$current = get_site_transient( 'update_themes' );
		$message_html = '';
		if ( isset( $current->response['throne'] ) ) {
			$message_html = '<span class="update-message">New update available!</span>
				<span class="update-actions">Version '.$current->response['throne']['new_version'].': <a href="http://mekshq.com/docs/throne-change-log" target="blank">See what\'s new</a><a href="'.admin_url( 'update-core.php' ).'">Update</a></span>';
		} else {
			$message_html = '<a class="theme-version-label" href="https://mekshq.com/docs/throne-change-log" target="blank">Version '.THRONE_THEME_VERSION.'</a>';
		}

		return $message_html;
	}
endif;


/**
 * Get Admin JS localized variables
 *
 * Function creates list of variables from theme to pass
 * them to global JS variable so we can use it in JS files
 *
 * @since  1.7.2
 *
 * @return array List of JS settings
 */
if ( !function_exists( 'thr_get_admin_js_settings' ) ):
	function thr_get_admin_js_settings() {

		$js_settings = array();
		$js_settings['ajax_url'] = admin_url( 'admin-ajax.php' );
		$js_settings['is_gutenberg'] = thr_is_gutenberg_page();
		return $js_settings;
	}
endif;


/**
 * Check if is Gutenberg page
 *
 * @return bool
 * @since  1.7.2
 */
if ( !function_exists( 'thr_is_gutenberg_page' ) ):
	function thr_is_gutenberg_page() {

		if ( function_exists( 'is_gutenberg_page' ) ) {
			return is_gutenberg_page();
		}
		
		global $wp_version;

		if( version_compare( $wp_version, '5', '<' ) ){
			return false;
		}

		global $current_screen;

		if ( ( $current_screen instanceof WP_Screen ) && !$current_screen->is_block_editor() ) {
			return false;
		}
		
		return true;
	}
endif;


/**
 * Check if Envato Market plugin is active
 *
 * @return bool
 * @since  1.7.3
 */
if ( !function_exists( 'thr_is_envato_market_active' ) ):
	function thr_is_envato_market_active() {
		return function_exists('envato_market');
	}
endif;


/**
 * Check if Redux Options framework is active
 *
 * @return bool
 * @since  1.0
 */
if ( !function_exists( 'thr_is_redux_active' ) ):
	function thr_is_redux_active() {
		return class_exists( 'ReduxFramework' );
	}
endif;


?>