<?php

/* Load frontend scripts and styles */
add_action( 'wp_enqueue_scripts', 'thr_load_scripts' );

/**
 * Load scripts and styles on frontend
 *
 * It just wraps two other separate functions for loading css and js files
 *
 * @since  1.8
 */

function thr_load_scripts() {
	thr_load_css();
	thr_load_js();
}



/**
 * Load frontend css files
 *
 * @since  1.8
 */
function thr_load_css() {

	//Load fonts
	if ( $fonts_link = thr_generate_font_links() ) {
		wp_enqueue_style( 'thr-fonts', $fonts_link, false, THRONE_THEME_VERSION );
	}

	//Load main css file
	wp_register_style( 'thr_style', get_parent_theme_file_uri( '/style.css' ), false, THRONE_THEME_VERSION);
	wp_enqueue_style( 'thr_style' );

	//Append dynamic css
	$thr_dynamic_css = thr_generate_dynamic_css();
	wp_add_inline_style( 'thr_style', $thr_dynamic_css );

	//Enqueue font awsm icons if css is not already included via plugin
	if ( !wp_style_is( 'mks_shortcodes_fntawsm_css', 'enqueued' ) ) {
		wp_register_style( 'thr_font_awesome',  get_parent_theme_file_uri( '/assets/css/font-awesome.min.css' ), false, THRONE_THEME_VERSION);
		wp_enqueue_style( 'thr_font_awesome' );
	}

	//Enqueue simple line icons if css is not already included via plugin
	if ( !wp_style_is( 'mks_shortcodes_simple_line_icons', 'enqueued' ) ) {
		wp_register_style( 'thr_icons',  get_parent_theme_file_uri( '/assets/css/simple-line-icons.css' ), false, THRONE_THEME_VERSION);
		wp_enqueue_style( 'thr_icons' );
	}

	//Load responsive css
	wp_register_style( 'thr_responsive',  get_parent_theme_file_uri( '/assets/css/responsive.css' ), array('thr_style'), THRONE_THEME_VERSION);
	wp_enqueue_style( 'thr_responsive' );
	

	//Load RTL css
	if ( thr_get_option( 'rtl_mode' ) ) {
		wp_register_style( 'thr_rtl',  get_parent_theme_file_uri( '/assets/css/rtl.css' ), false, THRONE_THEME_VERSION);
		wp_enqueue_style( 'thr_rtl' );
	}

}


/**
 * Load frontend js files
 *
 * @since  1.8
 */
function thr_load_js() {

	wp_enqueue_script( 'thr-match-height', get_parent_theme_file_uri( '/assets/js/jquery.matchHeight.js' ), array( 'jquery' ), THRONE_THEME_VERSION, true );
	wp_enqueue_script( 'thr-responsive-menu', get_parent_theme_file_uri( '/assets/js/jquery.sidr.js' ), array( 'jquery' ), THRONE_THEME_VERSION, true );

	if ( thr_get_option( 'lightbox' ) || thr_get_option( 'lightbox_content_img' ) ) {
		wp_enqueue_script( 'thr-magnific-popup', get_parent_theme_file_uri( '/assets/js/jquery.magnific-popup.min.js' ), array( 'jquery' ), THRONE_THEME_VERSION, true );
	}

	wp_enqueue_script( 'thr-fitvids', get_parent_theme_file_uri( '/assets/js/jquery.fitvids.js' ), array( 'jquery' ), THRONE_THEME_VERSION, true );
	
	wp_enqueue_script( 'thr-sticky', get_parent_theme_file_uri( '/assets/js/sticky-kit.js' ), array( 'jquery' ), THRONE_THEME_VERSION, true );
	
	wp_enqueue_script( 'thr-main', get_parent_theme_file_uri( '/assets/js/main.js' ), array( 'jquery', 'imagesloaded' ), THRONE_THEME_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	$thr_js_settings = thr_get_js_settings();
	wp_localize_script( 'thr-main', 'thr_js_settings', $thr_js_settings );
}