<?php

/* Add classes to body tag */
if ( !function_exists( 'thr_body_class' ) ):
	function thr_body_class( $classes ) {
	
		if ( ( $content_class = thr_get_option( 'main_content_style' ) ) != 'default' ) {
			$classes[] = $content_class;
		}

		if ( ( $sidebar_class = thr_get_option( 'sidebar_style' ) ) != 'default' ) {
			$classes[] = $sidebar_class;
		}

		global $thr_sidebar_opts;

		$thr_sidebar_opts = thr_get_current_sidebar();
		$sidebar_position_class = $thr_sidebar_opts['use_sidebar'] ? 'thr_body_sidebar_'.$thr_sidebar_opts['use_sidebar'] : 'no_sidebar';
		
		$classes[] = $sidebar_position_class;

		if( thr_get_option('sticky_header') ){
			$classes[] = 'sticky_on';
		}
		

		$classes[] = 'throne-v_' . str_replace('.', '_', THRONE_THEME_VERSION);

		if ( is_child_theme() ) {
			$classes[] = 'throne-child';
		}

		return $classes;
	}
endif;

add_filter( 'body_class', 'thr_body_class' );

/* Pre get posts - check if current archive template has posts in feature area to exclude those posts from main query */
if ( !function_exists( 'thr_pre_get_posts' ) ):
	function thr_pre_get_posts( $query ) {

		//Check for ppp value on specific archive layout
		if ( !is_admin() && $query->is_main_query() && $query->is_archive() ) {
			$current_layout = thr_get_posts_layout();
			$map = array(
				'layout-a' => 'lay_a',
				'layout-b' => 'lay_b',
				'layout-c' => 'lay_c',
				'layout-d' => 'lay_d'
			);
			if ( thr_get_option( $map[$current_layout].'_ppp' ) == 'custom' ) {
				$ppp_custom = absint( thr_get_option( $map[$current_layout].'_ppp_num' ) );
				$query->set( 'posts_per_page', $ppp_custom );
			}
		}

		//Exclude latest "x" posts if featured area is enabled on category, tag or author template
		if ( !is_admin() && $query->is_main_query() && ( $query->is_category() || $query->is_tag() || $query->is_author() ) && !$query->is_feed() ) {

			$offset = thr_get_current_fa_count();

			if ( $offset ) {
				//Next, determine how many posts per page you want (we'll use WordPress's settings)
				$ppp = isset( $ppp_custom ) ? $ppp_custom : get_option( 'posts_per_page' );

				//Next, detect and handle pagination...
				if ( $query->is_paged ) {

					//Manually determine page query offset (offset + current page (minus one) x posts per page)
					$page_offset = $offset + ( ( $query->query_vars['paged']-1 ) * $ppp );

					//Apply adjust page offset
					$query->set( 'offset', $page_offset );

				} else {

					//This is the first page. Just use the offset...
					$query->set( 'offset', $offset );

				}
			}

		}

	}
endif;

add_action( 'pre_get_posts', 'thr_pre_get_posts' );

/* Found posts - check if current archive template has posts in feature area to exclude those posts from main query */
if ( !function_exists( 'thr_adjust_offset_pagination' ) ):
	function thr_adjust_offset_pagination( $found_posts, $query ) {

		if ( !is_admin() && $query->is_main_query() && ( $query->is_category() || $query->is_tag() || $query->is_author() ) && !$query->is_feed() ) {

			$offset = thr_get_current_fa_count();

			if ( $offset ) {
				return $found_posts - $offset;
			} else {
				return $found_posts;
			}
		}

		return $found_posts;
	}
endif;

add_filter( 'found_posts', 'thr_adjust_offset_pagination', 1, 2 );


/* Add items dynamically to menu*/
if ( !function_exists( 'thr_extend_navigation' ) ):
	function thr_extend_navigation( $items, $args ) {
		if ( $args->theme_location == 'thr_main_navigation_menu' && thr_get_option( 'header_search' ) ) {
			$items .= '<li id="search_header_wrap"><a id="search_header" class="search_header" href="javascript:void(0)"><i class="fa fa-search"></i></a>';
			$items .= '<form class="search_header_form" action="'.esc_url( home_url( '/' ) ).'" method="get">
		<input name="s" class="search_input" size="20" type="text" value="'.__thr( 'search_form' ).'" onfocus="(this.value == \''.__thr( 'search_form' ).'\') && (this.value = \'\')" onblur="(this.value == \'\') && (this.value = \''.__thr( 'search_form' ).'\')" placeholder="'.__thr( 'search_form' ).'" />
		</form>';
			$items .= '</li>';
		}
		return $items;
	}
endif;

add_action( 'wp_nav_menu_items', 'thr_extend_navigation', 10, 2 );


/* Delete category custom meta from database on category deletion */
if ( !function_exists( 'thr_delete_category_meta' ) ):
	function thr_delete_category_meta( $term_id ) {
		delete_option( '_thr_category_'.$term_id );
	}
endif;

add_action( 'delete_category', 'thr_delete_category_meta' );

/* Set tag sizes in tag cloud widget */
if ( !function_exists( 'thr_set_tag_cloud_sizes' ) ):
	function thr_set_tag_cloud_sizes( $args ) {
		$args['smallest'] = 10;
		$args['largest'] = 20;
		return $args;
	}
endif;

add_filter( 'widget_tag_cloud_args', 'thr_set_tag_cloud_sizes' );

/* Change atts of wp gallery shortcode to get best sizes depends of column selection */
if ( !function_exists( 'thr_gallery_atts' ) ):
	function thr_gallery_atts( $out, $pairs, $atts ) {

		if ( !isset( $atts['columns'] ) ) {
			$atts['columns'] = 3;
		}

		if ( $atts['columns'] == 1 ) {
			$size = 'thr-layout-a';
			global $thr_sidebar_opts;
			if ( !$thr_sidebar_opts['use_sidebar'] ) {
				$size.='-nosid';
			}
		}  else if ( $atts['columns'] == 2 ) {
				$size = 'thr-fa-half';
			} else if ( $atts['columns'] == 3 ) {
				$size = 'thr-fa-third';
			} else if ( $atts['columns'] >= 4 && $atts['columns'] <= 6 ) {
				$size = 'thr-fa-quarter';
			} else {
			$size = 'thr-layout-d';
		}

		$out['columns'] = $atts['columns'];
		$out['size'] = $size;
		$out['link'] = 'file';

		return $out;

	}
endif;

add_filter( 'shortcode_atts_gallery', 'thr_gallery_atts', 10, 3 );

/* Change customize link to lead to theme options instead of live customizer */
if ( !function_exists( 'thr_change_customize_link' ) ):
	function thr_change_customize_link( $themes ) {
		if ( array_key_exists( 'throne', $themes ) ) {
			$themes['throne']['actions']['customize'] = admin_url( 'admin.php?page=thr_options' );
		}
		return $themes;
	}
endif;

add_filter( 'wp_prepare_themes_for_js', 'thr_change_customize_link' );


/* Add span element to post count number in category widget */
if ( !function_exists( 'thr_add_span_cat_count' ) ):
	function thr_add_span_cat_count( $links ) {
		$links = str_replace( '</a> (', '<span class="count">', $links );
		$links = str_replace( ')', '</span></a>', $links );
		return $links;
	}
endif;
add_filter( 'wp_list_categories', 'thr_add_span_cat_count' );


/* Prevent redirect issue that may brake home page pagination caused by some plugins */
if ( !function_exists( 'thr_disable_redirect_canonical' ) ):
	function thr_disable_redirect_canonical( $redirect_url ) {
		if ( is_page_template( 'template-home.php' ) && is_paged() ) {
			$redirect_url = false;
		}
		return $redirect_url;
	}
endif;

add_filter( 'redirect_canonical', 'thr_disable_redirect_canonical' );


/* Add class to image inside content so we can trigger pop-up safely */
if ( !function_exists( 'thr_add_content_image_class' ) ):
	function thr_add_content_image_class( $content ) {
		if ( thr_get_option( 'lightbox_content_img' ) ) {
			global $post;
			$pattern ="/<a(.*?)><img(.*?)>/i";
			$replacement = '<a$1 class="thr-popup"><img$2>';
			$content = preg_replace( $pattern, $replacement, $content );
		}
		return $content;
	}
endif;

add_filter( 'the_content', 'thr_add_content_image_class' );

/* Unregister Entry Views widget */
if ( !function_exists( 'thr_unregister_widgets' ) ):
	function thr_unregister_widgets() {

		$widgets = array( 'EV_Widget_Entry_Views' );

		//Allow child themes or plugins to add/remove widgets they want to unregister
		$widgets = apply_filters( 'thr_modify_unregister_widgets', $widgets );

		if ( !empty( $widgets ) ) {
			foreach ( $widgets as $widget ) {
				unregister_widget( $widget );
			}
		}

	}
endif;


add_action( 'widgets_init', 'thr_unregister_widgets', 99 );

/* Remove entry views support for other post types, we need post support only */
if ( !function_exists( 'thr_remove_entry_views_support' ) ):
	function thr_remove_entry_views_support() {

		$types = array( 'page', 'attachment', 'literature', 'portfolio_item', 'recipe', 'restaurant_item' );

		//Allow child themes or plugins to modify entry views support
		$widgets = apply_filters( 'thr_modify_entry_views_support', $types );

		if ( !empty( $types ) ) {
			foreach ( $types as $type ) {
				remove_post_type_support( $type, 'entry-views' );
			}
		}

	}
endif;

add_action( 'init', 'thr_remove_entry_views_support', 99 );

/**
 * Filter Function to add class to linked media image for popup
 *
 * @return   $content
 */

add_filter( 'the_content', 'thr_popup_media_in_content', 10, 1 );

if ( !function_exists( 'thr_popup_media_in_content' ) ):
	function thr_popup_media_in_content( $content ) {

		if ( thr_get_option( 'on_single_img_popup' ) ) {

			$pattern = "/<a(.*?)href=('|\")(.*?).(bmp|gif|jpeg|jpg|png)('|\")>/i";
			$replacement = '<a$1class="thr-popup-img" href=$2$3.$4$5>';
			$content = preg_replace( $pattern, $replacement, $content );
			return $content;
		}

		return  $content;
	}
endif;


/**
 * Add comment form default fields args filter 
 * to replace comment fields labels
 */

add_filter('comment_form_default_fields', 'thr_comment_fields_labels');

if(!function_exists('thr_comment_fields_labels')):
function thr_comment_fields_labels($fields){

	$replace = array(
		'author' => array(
			'old' => esc_html__( 'Name', 'throne' ),
			'new' =>__thr( 'comment_name' )
		),
		'email' => array(
			'old' => esc_html__( 'Email', 'throne' ),
			'new' =>__thr( 'comment_email' )
		),
		'url' => array(
			'old' => esc_html__( 'Website', 'throne' ),
			'new' =>__thr( 'comment_website' )
		),

		'cookies' => array(
			'old' => esc_html__( 'Save my name, email, and website in this browser for the next time I comment.', 'throne' ),
			'new' =>__thr( 'comment_cookie_gdpr' )
		)
	);

	foreach($fields as $key => $field){

		if(array_key_exists($key, $replace)){
			$fields[$key] = str_replace($replace[$key]['old'], $replace[$key]['new'], $fields[$key]);
		}

	}
	
	return $fields;

}

endif;


/**
 * Filter for social share options on frontend in the_content filter
 *
 * @param array $options - Array of options 
 * @return array
 * @since  1.7.5
 */
add_filter( 'meks_ess_modify_options', 'thr_social_share_modify_options' );

if ( !function_exists( 'thr_social_share_modify_options' ) ):
	function thr_social_share_modify_options( $options ) {

		$options['style'] = '5';
		$options['variant'] = '2';
		$options['color']['type'] = 'custom';
		$options['color']['custom_color'] = '#444444';
		$options['location'] = 'custom';
		$options['post_type'] = array('post');
		$options['label_share']['active'] = '0';

		return $options;
	}
endif;


?>