<?php 
/**
 * After Theme Setup
 *
 * Callback for after_theme_setup hook
 *
 * @since  1.8
 */

add_action( 'after_setup_theme', 'thr_theme_setup' );

function thr_theme_setup() {

	/* Define content width */
    $GLOBALS['content_width'] = 730;

    /* Localization */
    load_theme_textdomain( 'sidewalk', get_parent_theme_file_path( '/languages' ) );

	/* Load frontend scripts and styles */
	add_action( 'wp_enqueue_scripts', 'thr_load_scripts' );

	/* Load admin scripts and styles */
	add_action( 'admin_enqueue_scripts', 'thr_load_admin_scripts' );

	/* Register sidebars */
	add_action( 'widgets_init', 'thr_register_sidebars' );

	/* Register menus */
	add_action( 'init', 'thr_register_menus' );

	/* Add thumbnails support */
	add_theme_support( 'post-thumbnails' );

	/* Add theme support for title tag (since wp 4.1) */
	add_theme_support( 'title-tag' );


	/* Add image sizes */
	$image_sizes = thr_get_image_sizes();
	$image_sizes_opt = thr_get_option( 'image_sizes' );
	foreach ( $image_sizes as $id => $size ) {
		if ( isset( $image_sizes_opt[$id] ) && $image_sizes_opt[$id] ) {
			add_image_size( $id, $size['w'], $size['h'], $size['crop'] );
		}
	}

	/* Add post formats support */
	add_theme_support( 'post-formats', array(
			'audio', 'gallery', 'image', 'video'
		) );

	/* Support for HTML5 */
	add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form'  ) );

	/* Automatic Feed Links */
	add_theme_support( 'automatic-feed-links' );

	/* Support for editor styles */
    add_theme_support( 'editor-styles' );

    /* Load editor styles */
    if ( is_admin() ) {
        thr_load_editor_styles();
    }

    /* Support for alignwide elements */
    add_theme_support( 'align-wide' );

    /* Support for responsive embeds */
    add_theme_support( 'responsive-embeds' );

    /* Support for predefined colors in editor */
    add_theme_support( 'editor-color-palette', thr_get_editor_colors() );

    /* Support for predefined font-sizes in editor */
    add_theme_support( 'editor-font-sizes', thr_get_editor_font_sizes() );

}